@@ -69,8 +69,10 @@ def gen_stubs_and_deploy(service: str, lang: str, workdir: str, gcloud_project:
 
     docker_user = ""
     if OS_NAME == "linux":
-        # чтобы файлы не создавались из под рута
-        docker_user = "--user " + str(os.getuid()) + ":" + str(os.getgid())
+        # При переданном docker_user пользователю не хватает прав для подключения диска от контейнера gcloud-config,
+        # где ранее уже была получена авторизация для GCP. Права на созданные файлы устанавливаются в явном
+        # виде через chmod в entrypoint.py.
+        # docker_user = "--user " + str(os.getuid()) + ":" + str(os.getgid())
         build_dir = "/mnt/static"
     else:
         # на macos и win очень сложно создать /mnt/static и подмаунтить ее в докер
@@ -84,7 +86,7 @@ def gen_stubs_and_deploy(service: str, lang: str, workdir: str, gcloud_project:
         {docker_user} --volumes-from gcloud-config \
         -v {workdir}:/app_source \
         -v {build_dir}:/mnt/static \
-        apisgarpun/apiservice-deploy:latest \
+        apisgarpun/apiservice-deploy:0.3 \
         --service={service} \
         --lang={lang} \
         --gcloud_project={gcloud_project} \
